<template>
  <el-dialog
    :visible.sync="dialogVisible"
    @close="$emit('close-dialog')"
    @closed="closed"
    @open="open"
    title="添加巡检设备"
    width="800px"
  >
    <el-form
      ref="addForm"
      :rules="rules"
      :model="formData"
      label-width="120px"
      label-suffix=":"
    >
      <el-row>
        <el-col :span="12">
          <el-form-item label="产品" prop="productId">
            <el-cascader
              filterable
              v-model="formData.productId"
              :options="productData"
              :show-all-levels="false"
              ref="cascaderRef"
              :props="{
                label: 'name',
                value: 'id',
                children: 'children',
                emitPath:false
              }"
              style="width: 100%;"
              clearable
              placeholder="请选择产品"
              @change="deviceChange"
            >
            </el-cascader>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="设备" prop="id">
            <el-select
              placeholder="请选择设备"
              v-model="formData.id"
              clearable
              style="width: 100%;"
              filterable
              :disabled="!formData.productId"
            >
              <el-option
                v-for="item in deviceData"
                :key="item.value"
                :label="item.name"
                :value="item.value"
              />
            </el-select>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="派遣人员姓名" prop="linkName">
            <el-input
              :clearable="false"
              placeholder="请选择派遣人员姓名"
              v-model="formData.linkName"
              readonly
              class="readonly-input"
              @click.native="showDialog('userSelectDialog')"
            />
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="派遣人员电话" prop="linkPhone">
            <el-input
              :clearable="false"
              placeholder="请选择派遣人员电话"
              v-model="formData.linkPhone"
              readonly
              class="readonly-input"
              @click.native="showDialog('userSelectDialog')"
            />
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>

    <template v-slot:footer>
      <el-button
        type="primary"
        @click="handleSaveData"
      >
        保 存
      </el-button>
      <el-button @click="dialogVisible = false">取 消</el-button>
    </template>

    <user-select-dialog
      :userSelectDialog.sync="userSelectDialog"
      :userName="userName"
      @userChange="userChange"
    />
  </el-dialog>
</template>

<script>
import {
  deviceTable,
  equipmentAdd
} from '@/api/device/resourceInspection/inspectionLedger'
import UserSelectDialog from '../DeviceListPage/components/UserSelectDialog.vue'
import {getProductTree} from '@/api/device/resourceInspection/inspectionLedger'

export default {
  name: 'EquipmentAddDialog',
  components: {UserSelectDialog},
  props: {
    equipmentAddDialog: {
      default: false,
      type: Boolean
    },
    rowInfo: {
      default: _ => ({}),
      type: Object
    }
  },
  computed: {
    dialogVisible: {
      get() {
        return this.equipmentAddDialog
      },
      set(val) {
        this.$emit('update:equipmentAddDialog', val)
      }
    }
  },
  data() {
    return {
      formData: {
        id: ''
      },
      rules: {
        linkName: [
          {required: true, message: '派遣人员姓名不能为空', trigger: 'change'}
        ],
        linkPhone: [
          {required: false, message: '派遣人员电话不能为空', trigger: 'change'}
        ],
        productId: [
          {required: true, message: '产品不能为空', trigger: 'change'}
        ],
        id: [
          {required: true, message: '设备不能为空', trigger: 'change'}
        ],
        inspectionPlanId: [
          {required: true, message: '巡检计划不能为空', trigger: 'change'}
        ]
      },
      productData: [],  // 产品列表
      deviceData: [], // 设备列表
      userSelectDialog: false, // 人员选择弹层显隐
      userName: ''
    }
  },
  created() {
    this.loadProduct()
  },
  methods: {
    // 弹层打开
    open() {
      const {id: inspectionPlanId} = this.rowInfo
      this.formData = {
        ...this.formData,
        inspectionPlanId
      }
    },

    // 弹层关闭
    closed() {
      this.formData = this.$options.data().formData
      this.$refs.addForm.resetFields()
    },


    // 获取产品树形列表
    async loadProduct() {
      this.productData = (await getProductTree())?.value || []
    },

    // 设备切换
    async deviceChange(e) {
      this.formData.id = ''
      this.deviceData = []
      this.deviceData = ((await deviceTable(e))?.rows || []).map(i => {
        const {name, id} = i
        return {
          name,
          value: id
        }
      })
    },

    // 人员选择后
    userChange({linkName, linkPhone, personId}) {
      this.formData = {
        ...this.formData,
        linkName,
        linkPhone,
        personId
      }
    },

    // 展示弹层
    showDialog(dialog) {
      this[dialog] = true
      this.userName = this.formData.linkName || ''
    },

    // 保存
    handleSaveData() {
      this.$refs.addForm.validate(async (valid, object) => {
        if (!valid) {
          this.$message.warning(`有${Object.keys(object).length}个字段未通过校验，请正确填写表单内容。`)
        } else {
          const {state} = await equipmentAdd(this.formData)
          if (state) {
            this.$message.success('日常台账信息新增成功')
            this.dialogVisible = false
            this.$emit('closeDialog', 'add')
          } else {
            this.$message.error(message + '日常台账信息编辑失败')
          }
        }
      })
    }
  }
}
</script>
<style lang="scss" scoped>
::v-deep .readonly-input {

  .el-input__inner {
    cursor: pointer;
  }
}
</style>
